@@ -44,8 +44,8 @@ function() {
         .to_num(getOption("values.cex")), "\n")
     cat("values.digits .... Decimal digits on bars, pie ",
         .to_num(getOption("values.digits")), "\n")
-    cat("values.pos ....... Position of values ...... ..",
-        .to_str(getOption("values.pos")), "\n")
+    cat("values.position ....... Position of values ...... ..",
+        .to_str(getOption("values.position")), "\n")
 
     cat("\n")
     cat("pt.fill .......... Point fill color ..........",
